/**
 * 接口响应
 * @param msg 信息提示
 * @param code 信息码
 * @param data 数据
 */
interface IResponse<T = any> {
  msg: string;
  code: number;
  data: T;
}

/**
 * 列表
 * @param list 数据列表
 * @param total 数据列表数量
 */
interface IList<T = Record<string, any>> {
  list: T;
  total: string;
}

/**
 * 用户信息
 * @param idStr 主键字符串
 * @param email email地址
 * @param image 用户头像
 * @param address 地址
 * @param nickName 昵称
 * @param loginName 登录名
 * @param authStatus 认证状态
 * @param mobilePhone 手机号
 */
interface IUser {
  idStr: string;
  email?: string;
  image?: string;
  address?: string;
  nickName?: string;
  loginName: string;
  mobilePhone?: string;
}

/**
 * 用户类型
 * @param ID 企业/个人主键
 * @param Type 1个人、0企业
 * @param Date 套餐日期
 */
interface IUserType {
  ID: string;
  Type: number;
  Date?: string;
}

/**
 * 分页
 * @param name 名称
 * @param size 页大小
 * @param current 当前页
 */
type IPage = {
  size: string | number;
  current: string | number;
};
